| Title: | Explore Data with Plots and Tables |
|---|---|
| Description: | Provides modular functions and applications for quickly generating plots and tables. Each modular function opens a graphical user interface providing the user with options to create and customise plots and tables. |
| Authors: | Joe Chelladurai [aut, cre] (ORCID: <https://orcid.org/0000-0001-8477-3753>) |
| Maintainer: | Joe Chelladurai <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.2 |
| Built: | 2026-05-26 10:11:16 UTC |
| Source: | https://github.com/joe-chelladurai/starry |
Plot - Bar
plot_bar( data, y, bar_width, fill, outline, position, labels, row, prop, column, theme, title, subtitle, xlab, ylab, caption, code )plot_bar( data, y, bar_width, fill, outline, position, labels, row, prop, column, theme, title, subtitle, xlab, ylab, caption, code )
data |
data |
y |
variable on y axis |
bar_width |
width of bar |
fill |
fill |
outline |
outline |
position |
position of bars |
labels |
data labels |
row |
facet row in grid |
prop |
proportion |
column |
facet column in grid |
theme |
theme of plot |
title |
title of plot |
subtitle |
subtitle of plot |
xlab |
x-axis |
ylab |
y-axis label |
caption |
caption |
code |
add custom code |
No return value. This function is called for the side effect of launching a shiny application.
if (interactive()) { plot_bar(mtcars) }if (interactive()) { plot_bar(mtcars) }
Plot - Box
plot_box( data, x, y, theme, box_width, fill, outline, row, column, width, height, title, subtitle, xlab, ylab, caption, show_code, code )plot_box( data, x, y, theme, box_width, fill, outline, row, column, width, height, title, subtitle, xlab, ylab, caption, show_code, code )
data |
data |
x |
variable on x axis |
y |
variable on y axis |
theme |
theme of plot |
box_width |
width of box |
fill |
fill |
outline |
outline |
row |
facet row in grid |
column |
facet column in grid |
width |
width of plot |
height |
height of plot |
title |
title of plot |
subtitle |
subtitle of plot |
xlab |
x-axis |
ylab |
y-axis label |
caption |
caption |
show_code |
show the generated code TRUE or FALSE, (default TRUE) |
code |
add custom code |
No return value. This function is called for the side effect of launching a shiny application.
if (interactive()) { plot_box(mtcars) }if (interactive()) { plot_box(mtcars) }
Plot - Density
plot_density( data, xvar, fill, outline, row, column, height, width, theme, title, subtitle, caption, xlab, ylab, code, show_code )plot_density( data, xvar, fill, outline, row, column, height, width, theme, title, subtitle, caption, xlab, ylab, code, show_code )
data |
data |
xvar |
xvar |
fill |
fill |
outline |
outline |
row |
facet row in grid |
column |
facet column in grid |
height |
height of plot |
width |
width of plot |
theme |
theme |
title |
title of plot |
subtitle |
subtitle of plot |
caption |
caption |
xlab |
x-axis |
ylab |
y-axis label |
code |
additional code |
show_code |
show/hide code |
No return value. This function is called for the side effect of launching a shiny application.
if (interactive()) { plot_density(mtcars) }if (interactive()) { plot_density(mtcars) }
Plot - Histogram
plot_histogram( data, xvar, fill, outline, row, column, width, height, title, subtitle, xlab, ylab, caption, theme, code, show_code )plot_histogram( data, xvar, fill, outline, row, column, width, height, title, subtitle, xlab, ylab, caption, theme, code, show_code )
data |
data |
xvar |
xvar |
fill |
fill |
outline |
outline |
row |
facet row in grid |
column |
facet column in grid |
width |
width of plot |
height |
height of plot |
title |
title of plot |
subtitle |
subtitle of plot |
xlab |
x-axis |
ylab |
y-axis label |
caption |
caption |
theme |
theme |
code |
additional code |
show_code |
show/hide code |
No return value. This function is called for the side effect of launching a shiny application.
if (interactive()) { plot_histogram(mtcars) }if (interactive()) { plot_histogram(mtcars) }
Plot - Line
plot_line( data, xvar, yvar, theme, group, attr, code, row, column, width, height, title, subtitle, xlab, ylab, caption, show_code )plot_line( data, xvar, yvar, theme, group, attr, code, row, column, width, height, title, subtitle, xlab, ylab, caption, show_code )
data |
data |
xvar |
xvar |
yvar |
yvar |
theme |
theme |
group |
group |
attr |
attr |
code |
additional code |
row |
facet row in grid |
column |
facet column in grid |
width |
width of plot |
height |
height of plot |
title |
title of plot |
subtitle |
subtitle of plot |
xlab |
x-axis |
ylab |
y-axis label |
caption |
caption |
show_code |
show/hide code |
No return value. This function is called for the side effect of launching a shiny application.
if (interactive()) { plot_line(mtcars) }if (interactive()) { plot_line(mtcars) }
Plot - Scatter
plot_scatter( data, xvar, yvar, color, shape, size, row, column, title, subtitle, caption, xlab, ylab, theme )plot_scatter( data, xvar, yvar, color, shape, size, row, column, title, subtitle, caption, xlab, ylab, theme )
data |
data |
xvar |
x |
yvar |
y |
color |
color |
shape |
shape |
size |
size |
row |
row |
column |
column |
title |
title |
subtitle |
subtitle |
caption |
caption |
xlab |
x axis label |
ylab |
y axis label |
theme |
theme |
No return value. This function is called for the side effect of launching a shiny application.
if (interactive()) { plot_scatter(mtcars) }if (interactive()) { plot_scatter(mtcars) }
Stat - Anova
stat_anova(data, xvar, yvar, code, show_code)stat_anova(data, xvar, yvar, code, show_code)
data |
data |
xvar |
xvar |
yvar |
yvar |
code |
additional code |
show_code |
show/hide code |
No return value. This function is called for the side effect of launching a shiny application.
if (interactive()) { stat_regression_linear(mtcars) }if (interactive()) { stat_regression_linear(mtcars) }
Stat - Correlation
stat_correlation(data, xvar, code, show_code)stat_correlation(data, xvar, code, show_code)
data |
data |
xvar |
list of variables |
code |
additional code |
show_code |
show/hide code |
No return value. This function is called for the side effect of launching a shiny application.
if (interactive()) { stat_frequency(mtcars) }if (interactive()) { stat_frequency(mtcars) }
Stat - Frequency
stat_frequency(data, xvar, show_code)stat_frequency(data, xvar, show_code)
data |
data |
xvar |
variable |
show_code |
show/hide code |
No return value. This function is called for the side effect of launching a shiny application.
if (interactive()) { stat_frequency(mtcars) }if (interactive()) { stat_frequency(mtcars) }
Stat - Linear Regression
stat_regression_linear(data, xvar, yvar, code, show_code)stat_regression_linear(data, xvar, yvar, code, show_code)
data |
data |
xvar |
xvar |
yvar |
yvar |
code |
additional code |
show_code |
show/hide code |
No return value. This function is called for the side effect of launching a shiny application.
if (interactive()) { stat_regression_linear(mtcars) }if (interactive()) { stat_regression_linear(mtcars) }
Stat - T-test
stat_ttest(data, xvar, yvar, group, test, show_code)stat_ttest(data, xvar, yvar, group, test, show_code)
data |
data |
xvar |
xvar |
yvar |
yvar |
group |
groups |
test |
type of t-test |
show_code |
show/hide code |
No return value. This function is called for the side effect of launching a shiny application.
if (interactive()) { stat_ttest(mtcars) }if (interactive()) { stat_ttest(mtcars) }